@@ -18,8 +18,6 @@ use Symfony\Component\DependencyInjection\Exception\OutOfBoundsException;
  * Definition represents a service definition.
  *
  * @author Fabien Potencier <fabien@symfony.com>
- *
- * @api
  */
 class Definition
 {
@@ -48,8 +46,6 @@ class Definition
      *
      * @param string|null $class     The service class
      * @param array       $arguments An array of arguments to pass to the service constructor
-     *
-     * @api
      */
     public function __construct($class = null, array $arguments = array())
     {
@@ -93,8 +89,6 @@ class Definition
      *
      * @return Definition The current instance
      *
-     * @api
-     *
      * @deprecated since version 2.6, to be removed in 3.0.
      */
     public function setFactoryClass($factoryClass)
@@ -111,8 +105,6 @@ class Definition
      *
      * @return string|null The factory class name
      *
-     * @api
-     *
      * @deprecated since version 2.6, to be removed in 3.0.
      */
     public function getFactoryClass($triggerDeprecationError = true)
@@ -131,8 +123,6 @@ class Definition
      *
      * @return Definition The current instance
      *
-     * @api
-     *
      * @deprecated since version 2.6, to be removed in 3.0.
      */
     public function setFactoryMethod($factoryMethod)
@@ -184,8 +174,6 @@ class Definition
      *
      * @return string|null The factory method name
      *
-     * @api
-     *
      * @deprecated since version 2.6, to be removed in 3.0.
      */
     public function getFactoryMethod($triggerDeprecationError = true)
@@ -204,8 +192,6 @@ class Definition
      *
      * @return Definition The current instance
      *
-     * @api
-     *
      * @deprecated since version 2.6, to be removed in 3.0.
      */
     public function setFactoryService($factoryService)
@@ -222,8 +208,6 @@ class Definition
      *
      * @return string|null The factory service id
      *
-     * @api
-     *
      * @deprecated since version 2.6, to be removed in 3.0.
      */
     public function getFactoryService($triggerDeprecationError = true)
@@ -241,8 +225,6 @@ class Definition
      * @param string $class The service class
      *
      * @return Definition The current instance
-     *
-     * @api
      */
     public function setClass($class)
     {
@@ -255,8 +237,6 @@ class Definition
      * Gets the service class.
      *
      * @return string|null The service class
-     *
-     * @api
      */
     public function getClass()
     {
@@ -269,8 +249,6 @@ class Definition
      * @param array $arguments An array of arguments
      *
      * @return Definition The current instance
-     *
-     * @api
      */
     public function setArguments(array $arguments)
     {
@@ -279,9 +257,6 @@ class Definition
         return $this;
     }
 
-    /**
-     * @api
-     */
     public function setProperties(array $properties)
     {
         $this->properties = $properties;
@@ -289,17 +264,11 @@ class Definition
         return $this;
     }
 
-    /**
-     * @api
-     */
     public function getProperties()
     {
         return $this->properties;
     }
 
-    /**
-     * @api
-     */
     public function setProperty($name, $value)
     {
         $this->properties[$name] = $value;
@@ -313,8 +282,6 @@ class Definition
      * @param mixed $argument An argument
      *
      * @return Definition The current instance
-     *
-     * @api
      */
     public function addArgument($argument)
     {
@@ -332,8 +299,6 @@ class Definition
      * @return Definition The current instance
      *
      * @throws OutOfBoundsException When the replaced argument does not exist
-     *
-     * @api
      */
     public function replaceArgument($index, $argument)
     {
@@ -350,8 +315,6 @@ class Definition
      * Gets the arguments to pass to the service constructor/factory method.
      *
      * @return array The array of arguments
-     *
-     * @api
      */
     public function getArguments()
     {
@@ -366,8 +329,6 @@ class Definition
      * @return mixed The argument value
      *
      * @throws OutOfBoundsException When the argument does not exist
-     *
-     * @api
      */
     public function getArgument($index)
     {
@@ -384,8 +345,6 @@ class Definition
      * @param array $calls An array of method calls
      *
      * @return Definition The current instance
-     *
-     * @api
      */
     public function setMethodCalls(array $calls = array())
     {
@@ -406,8 +365,6 @@ class Definition
      * @return Definition The current instance
      *
      * @throws InvalidArgumentException on empty $method param
-     *
-     * @api
      */
     public function addMethodCall($method, array $arguments = array())
     {
@@ -425,8 +382,6 @@ class Definition
      * @param string $method The method name to remove
      *
      * @return Definition The current instance
-     *
-     * @api
      */
     public function removeMethodCall($method)
     {
@@ -446,8 +401,6 @@ class Definition
      * @param string $method The method name to search for
      *
      * @return bool
-     *
-     * @api
      */
     public function hasMethodCall($method)
     {
@@ -464,8 +417,6 @@ class Definition
      * Gets the methods to call after service initialization.
      *
      * @return array An array of method calls
-     *
-     * @api
      */
     public function getMethodCalls()
     {
@@ -478,8 +429,6 @@ class Definition
      * @param array $tags
      *
      * @return Definition the current instance
-     *
-     * @api
      */
     public function setTags(array $tags)
     {
@@ -492,8 +441,6 @@ class Definition
      * Returns all tags.
      *
      * @return array An array of tags
-     *
-     * @api
      */
     public function getTags()
     {
@@ -506,8 +453,6 @@ class Definition
      * @param string $name The tag name
      *
      * @return array An array of attributes
-     *
-     * @api
      */
     public function getTag($name)
     {
@@ -521,8 +466,6 @@ class Definition
      * @param array  $attributes An array of attributes
      *
      * @return Definition The current instance
-     *
-     * @api
      */
     public function addTag($name, array $attributes = array())
     {
@@ -537,8 +480,6 @@ class Definition
      * @param string $name
      *
      * @return bool
-     *
-     * @api
      */
     public function hasTag($name)
     {
@@ -554,9 +495,7 @@ class Definition
      */
     public function clearTag($name)
     {
-        if (isset($this->tags[$name])) {
-            unset($this->tags[$name]);
-        }
+        unset($this->tags[$name]);
 
         return $this;
     }
@@ -565,8 +504,6 @@ class Definition
      * Clears the tags for this definition.
      *
      * @return Definition The current instance
-     *
-     * @api
      */
     public function clearTags()
     {
@@ -581,8 +518,6 @@ class Definition
      * @param string $file A full pathname to include
      *
      * @return Definition The current instance
-     *
-     * @api
      */
     public function setFile($file)
     {
@@ -595,8 +530,6 @@ class Definition
      * Gets the file to require before creating the service.
      *
      * @return string|null The full pathname to include
-     *
-     * @api
      */
     public function getFile()
     {
@@ -609,8 +542,6 @@ class Definition
      * @param string $scope Whether the service must be shared or not
      *
      * @return Definition The current instance
-     *
-     * @api
      */
     public function setScope($scope)
     {
@@ -623,8 +554,6 @@ class Definition
      * Returns the scope of the service.
      *
      * @return string
-     *
-     * @api
      */
     public function getScope()
     {
@@ -637,8 +566,6 @@ class Definition
      * @param bool $boolean
      *
      * @return Definition The current instance
-     *
-     * @api
      */
     public function setPublic($boolean)
     {
@@ -651,8 +578,6 @@ class Definition
      * Whether this service is public facing.
      *
      * @return bool
-     *
-     * @api
      */
     public function isPublic()
     {
@@ -666,8 +591,6 @@ class Definition
      *
      * @return Definition The current instance
      *
-     * @api
-     *
      * @deprecated since version 2.7, will be removed in 3.0.
      */
     public function setSynchronized($boolean, $triggerDeprecationError = true)
@@ -686,8 +609,6 @@ class Definition
      *
      * @return bool
      *
-     * @api
-     *
      * @deprecated since version 2.7, will be removed in 3.0.
      */
     public function isSynchronized($triggerDeprecationError = true)
@@ -730,8 +651,6 @@ class Definition
      * @param bool $boolean
      *
      * @return Definition the current instance
-     *
-     * @api
      */
     public function setSynthetic($boolean)
     {
@@ -745,8 +664,6 @@ class Definition
      * container, but dynamically injected.
      *
      * @return bool
-     *
-     * @api
      */
     public function isSynthetic()
     {
@@ -760,8 +677,6 @@ class Definition
      * @param bool $boolean
      *
      * @return Definition the current instance
-     *
-     * @api
      */
     public function setAbstract($boolean)
     {
@@ -775,8 +690,6 @@ class Definition
      * template for other definitions.
      *
      * @return bool
-     *
-     * @api
      */
     public function isAbstract()
     {
@@ -789,8 +702,6 @@ class Definition
      * @param callable $callable A PHP callable
      *
      * @return Definition The current instance
-     *
-     * @api
      */
     public function setConfigurator($callable)
     {
@@ -803,8 +714,6 @@ class Definition
      * Gets the configurator to call after the service is fully initialized.
      *
      * @return callable|null The PHP callable to call
-     *
-     * @api
      */
     public function getConfigurator()
     {
